@@ -1,3 +1,4 @@
 #!/bin/bash
 set -Eeuo pipefail
-cargo clippy
+
+cargo clippy --all-targets
