@@ -1,5 +1,5 @@
 #!/usr/bin/env node
 
-const bin = require("./bin")
+const bin = require("./bin");
 
 bin.run("hurl");
\ No newline at end of file
