@@ -1,5 +1,5 @@
 #!/bin/bash
 set -Eeuo pipefail
 
-export HURL_name=Bob
+export HURL_VARIABLE_name=Bob
 hurl tests_ok/env_var/env_var.hurl
