@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2024 Orange
+ * Copyright (C) 2025 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -222,7 +222,7 @@ pub fn whitespace(reader: &mut Reader) {
 
 #[cfg(test)]
 mod tests {
-    use hurl_core::reader::Pos;
+    use hurl_core::reader::{CharPos, Pos};
 
     use super::*;
 
@@ -230,15 +230,15 @@ mod tests {
     fn test_natural() {
         let mut reader = Reader::new("0");
         assert_eq!(natural(&mut reader).unwrap(), 0);
-        assert_eq!(reader.cursor().index, 1);
+        assert_eq!(reader.cursor().index, CharPos(1));
 
         let mut reader = Reader::new("0.");
         assert_eq!(natural(&mut reader).unwrap(), 0);
-        assert_eq!(reader.cursor().index, 1);
+        assert_eq!(reader.cursor().index, CharPos(1));
 
         let mut reader = Reader::new("10x");
         assert_eq!(natural(&mut reader).unwrap(), 10);
-        assert_eq!(reader.cursor().index, 2);
+        assert_eq!(reader.cursor().index, CharPos(2));
     }
 
     #[test]
@@ -284,11 +284,11 @@ mod tests {
     fn test_number() {
         let mut reader = Reader::new("1");
         assert_eq!(number(&mut reader).unwrap(), Number { int: 1, decimal: 0 });
-        assert_eq!(reader.cursor().index, 1);
+        assert_eq!(reader.cursor().index, CharPos(1));
 
         let mut reader = Reader::new("1.0");
         assert_eq!(number(&mut reader).unwrap(), Number { int: 1, decimal: 0 });
-        assert_eq!(reader.cursor().index, 3);
+        assert_eq!(reader.cursor().index, CharPos(3));
 
         let mut reader = Reader::new("-1.0");
         assert_eq!(
@@ -298,7 +298,7 @@ mod tests {
                 decimal: 0
             }
         );
-        assert_eq!(reader.cursor().index, 4);
+        assert_eq!(reader.cursor().index, CharPos(4));
 
         let mut reader = Reader::new("1.1");
         assert_eq!(
@@ -308,7 +308,7 @@ mod tests {
                 decimal: 100_000_000_000_000_000
             }
         );
-        assert_eq!(reader.cursor().index, 3);
+        assert_eq!(reader.cursor().index, CharPos(3));
 
         let mut reader = Reader::new("1.100");
         assert_eq!(
@@ -318,7 +318,7 @@ mod tests {
                 decimal: 100_000_000_000_000_000
             }
         );
-        assert_eq!(reader.cursor().index, 5);
+        assert_eq!(reader.cursor().index, CharPos(5));
 
         let mut reader = Reader::new("1.01");
         assert_eq!(
@@ -328,7 +328,7 @@ mod tests {
                 decimal: 10_000_000_000_000_000
             }
         );
-        assert_eq!(reader.cursor().index, 4);
+        assert_eq!(reader.cursor().index, CharPos(4));
 
         let mut reader = Reader::new("1.010");
         assert_eq!(
@@ -338,7 +338,7 @@ mod tests {
                 decimal: 10_000_000_000_000_000
             }
         );
-        assert_eq!(reader.cursor().index, 5);
+        assert_eq!(reader.cursor().index, CharPos(5));
 
         let mut reader = Reader::new("-0.333333333333333333");
         assert_eq!(
@@ -348,7 +348,7 @@ mod tests {
                 decimal: 333_333_333_333_333_333
             }
         );
-        assert_eq!(reader.cursor().index, 21);
+        assert_eq!(reader.cursor().index, CharPos(21));
     }
 
     #[test]
@@ -434,28 +434,28 @@ mod tests {
     fn test_literal() {
         let mut reader = Reader::new("hello");
         assert_eq!(literal("hello", &mut reader), Ok(()));
-        assert_eq!(reader.cursor().index, 5);
+        assert_eq!(reader.cursor().index, CharPos(5));
 
         let mut reader = Reader::new("hello ");
         assert_eq!(literal("hello", &mut reader), Ok(()));
-        assert_eq!(reader.cursor().index, 6);
+        assert_eq!(reader.cursor().index, CharPos(6));
 
         let mut reader = Reader::new("");
         let error = literal("hello", &mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 1 });
         assert_eq!(error.kind, ParseErrorKind::Expecting("hello".to_string()));
-        assert_eq!(reader.cursor().index, 0);
+        assert_eq!(reader.cursor().index, CharPos(0));
 
         let mut reader = Reader::new("hi");
         let error = literal("hello", &mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 1 });
         assert_eq!(error.kind, ParseErrorKind::Expecting("hello".to_string()));
-        assert_eq!(reader.cursor().index, 2);
+        assert_eq!(reader.cursor().index, CharPos(2));
 
         let mut reader = Reader::new("he");
         let error = literal("hello", &mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 1 });
         assert_eq!(error.kind, ParseErrorKind::Expecting("hello".to_string()));
-        assert_eq!(reader.cursor().index, 2);
+        assert_eq!(reader.cursor().index, CharPos(2));
     }
 }
