@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2024 Orange
+ * Copyright (C) 2025 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -35,6 +35,7 @@ pub enum ElementKind {
     Svg,          // https://developer.mozilla.org/en-US/docs/Web/SVG/Element/svg
     Symbol,       // https://developer.mozilla.org/en-US/docs/Web/SVG/Element/symbol
     Text,         // https://developer.mozilla.org/en-US/docs/Web/SVG/Element/text
+    Title,        // https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title
     Use,          // https://developer.mozilla.org/en-US/docs/Web/SVG/Element/use
 }
 
@@ -54,6 +55,7 @@ impl ElementKind {
             ElementKind::Svg => "svg",
             ElementKind::Symbol => "symbol",
             ElementKind::Text => "text",
+            ElementKind::Title => "title",
             ElementKind::Use => "use",
         }
     }
@@ -130,41 +132,41 @@ impl Element {
     }
 
     /// Serializes this element to a SVG string.
-    fn to_svg(&self) -> String {
+    fn to_svg(&self, buffer: &mut String) {
         let name = self.kind().name();
 
-        let mut s = String::from("<");
-        s.push_str(name);
+        buffer.push('<');
+        buffer.push_str(name);
 
         if self.kind() == ElementKind::Svg {
             // Attributes specific to svg
-            push_attr(&mut s, "xmlns", "http://www.w3.org/2000/svg");
+            push_attr(buffer, "xmlns", "http://www.w3.org/2000/svg");
         }
 
         for att in self.attrs() {
-            s.push(' ');
-            s.push_str(&att.to_string());
+            buffer.push(' ');
+            buffer.push_str(&att.to_string());
         }
 
         if self.has_children() || self.has_content() {
-            s.push('>');
+            buffer.push('>');
             for child in self.children() {
-                s.push_str(&child.to_svg());
+                child.to_svg(buffer);
             }
-            s.push_str(self.content());
-            s.push_str("</");
-            s.push_str(name);
-            s.push('>');
+            buffer.push_str(self.content());
+            buffer.push_str("</");
+            buffer.push_str(name);
+            buffer.push('>');
         } else {
-            s.push_str(" />");
+            buffer.push_str(" />");
         }
-        s
     }
 }
 
 impl fmt::Display for Element {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        let text = self.to_svg();
+        let mut text = String::new();
+        self.to_svg(&mut text);
         f.write_str(&text)
     }
 }
@@ -363,6 +365,13 @@ pub fn new_use() -> Element {
     Element::new(ElementKind::Use)
 }
 
+/// Returns a new `<title>` element.
+pub fn new_title(content: &str) -> Element {
+    let mut elt = Element::new(ElementKind::Title);
+    elt.set_content(content);
+    elt
+}
+
 #[cfg(test)]
 mod tests {
     use super::Attribute::*;
