@@ -20,12 +20,13 @@ use std::path::Path;
 
 use hurl::parallel::job::{Job, JobResult};
 use hurl::parallel::runner::ParallelRunner;
+use hurl::pretty::PrettyMode;
 use hurl::runner::{HurlResult, Output, VariableSet};
 use hurl::util::term::{Stdout, WriteMode};
 use hurl::{output, parallel, runner};
 use hurl_core::error::{DisplaySourceError, OutputFormat};
 use hurl_core::input::Input;
-use hurl_core::typing::Count;
+use hurl_core::types::Count;
 
 use crate::cli::options::CliOptions;
 use crate::cli::CliError;
@@ -127,6 +128,7 @@ fn print_output(
             hurl_result,
             options.include,
             options.color,
+            options.pretty,
             options.output.as_ref(),
             stdout,
             append,
@@ -182,9 +184,10 @@ pub fn run_par(
     options.secrets.iter().for_each(|(name, value)| {
         variables.insert_secret(name.clone(), value.clone());
     });
-    let output_type = options
-        .output_type
-        .to_output_type(options.include, options.color);
+    let output_type =
+        options
+            .output_type
+            .to_output_type(options.include, options.color, options.pretty);
     let max_width = terminal_size::terminal_size().map(|(w, _)| w.0 as usize);
     let jobs = files
         .iter()
@@ -221,11 +224,17 @@ impl From<JobResult> for HurlRun {
 }
 
 impl cli::OutputType {
-    fn to_output_type(&self, include_headers: bool, color: bool) -> parallel::runner::OutputType {
+    fn to_output_type(
+        &self,
+        include_headers: bool,
+        color: bool,
+        pretty: PrettyMode,
+    ) -> parallel::runner::OutputType {
         match self {
             cli::OutputType::ResponseBody => parallel::runner::OutputType::ResponseBody {
                 include_headers,
                 color,
+                pretty,
             },
             cli::OutputType::Json => parallel::runner::OutputType::Json,
             cli::OutputType::NoOutput => parallel::runner::OutputType::NoOutput,
@@ -296,7 +305,7 @@ impl Iterator for InputQueue<'_> {
 #[cfg(test)]
 mod tests {
     use hurl_core::input::Input;
-    use hurl_core::typing::Count;
+    use hurl_core::types::Count;
 
     use crate::run::InputQueue;
 
