@@ -24,7 +24,8 @@ use hurl_core::error::DisplaySourceError;
 use hurl_core::text::{Style, StyledString};
 
 use crate::http::HttpError;
-use crate::runner::diff::DiffHunk;
+
+use super::diff::DiffHunk;
 
 /// Represents a single instance of a runtime error, usually triggered by running a
 /// [`hurl_core::ast::Entry`]. Running a Hurl content (see [`crate::runner::run`]) returns a list of
@@ -85,6 +86,10 @@ pub enum RunnerErrorKind {
         error: String,
     },
     FilterDecode(String),
+    FilterDateParsingError {
+        date: String,
+        format: String,
+    },
     FilterInvalidEncoding(String),
     /// Input of the filter is not valid, with a given reason.
     FilterInvalidInput(String),
@@ -143,6 +148,7 @@ impl DisplaySourceError for RunnerError {
             RunnerErrorKind::ExpressionInvalidType { .. } => "Invalid expression type".to_string(),
             RunnerErrorKind::FileReadAccess { .. } => "File read access".to_string(),
             RunnerErrorKind::FileWriteAccess { .. } => "File write access".to_string(),
+            RunnerErrorKind::FilterDateParsingError { .. } => "Filter error".to_string(),
             RunnerErrorKind::FilterDecode { .. } => "Filter error".to_string(),
             RunnerErrorKind::FilterInvalidEncoding { .. } => "Filter error".to_string(),
             RunnerErrorKind::FilterInvalidInput { .. } => "Filter error".to_string(),
@@ -233,6 +239,11 @@ impl DisplaySourceError for RunnerError {
                 let message = error::add_carets(message, self.source_info, content);
                 color_red_multiline_string(&message)
             }
+            RunnerErrorKind::FilterDateParsingError { date, format } => {
+                let message = &format!("value <{date}> could not be parsed with <{format}> format");
+                let message = error::add_carets(message, self.source_info, content);
+                color_red_multiline_string(&message)
+            }
             RunnerErrorKind::FilterDecode(encoding) => {
                 let message = &format!("value can not be decoded with <{encoding}> encoding");
                 let message = error::add_carets(message, self.source_info, content);
